@@ -1,12 +1,5 @@
 from app_utils.django import clean_setting
 
-MININGTAXES_TAX_CACHE_VIEW_TIMEOUT = clean_setting(
-    "MININGTAXES_TAX_CACHE_VIEW_TIMEOUT", 60 * 60 * 6
-)
-"""Number of seconds before view cache expires.
-"""
-
-
 MININGTAXES_TAX_ONLY_CORP_MOONS = clean_setting("MININGTAXES_TAX_ONLY_CORP_MOONS", True)
 """Only tax corporate moons using moon observers as opposed to all moons appearing
 in the personal mining ledgers.
@@ -31,7 +24,9 @@ MININGTAXES_TASKS_TIME_LIMIT = clean_setting("MININGTAXES_TASKS_TIME_LIMIT", 720
 MININGTAXES_REFINED_RATE = clean_setting("MININGTAXES_REFINED_RATE", 0.9063)
 """Refining rate for ores."""
 
-MININGTAXES_UNKNOWN_TAX_RATE = 0.10
+MININGTAXES_UNKNOWN_TAX_RATE = clean_setting("MININGTAXES_UNKNOWN_TAX_RATE", 0.10)
+
+MININGTAXES_ALWAYS_TAX_REFINED = clean_setting("MININGTAXES_ALWAYS_TAX_REFINED", False)
 
 MININGTAXES_PRICE_SOURCE_ID = clean_setting("MININGTAXES_PRICE_SOURCE_ID", 60003760)
 
@@ -40,3 +35,5 @@ MININGTAXES_PRICE_SOURCE_NAME = clean_setting("MININGTAXES_PRICE_SOURCE_NAME", "
 MININGTAXES_PRICE_METHOD = clean_setting("MININGTAXES_PRICE_METHOD", "Fuzzwork")
 
 MININGTAXES_PRICE_JANICE_API_KEY = clean_setting("MININGTAXES_PRICE_JANICE_API_KEY", "")
+
+MININGTAXES_BLACKLIST = clean_setting("MININGTAXES_BLACKLIST", [])
