@@ -1,5 +1,3 @@
-from datetime import date
-
 import requests
 from celery import shared_task
 
@@ -7,7 +5,6 @@ from django.db import Error
 from django.http.response import Http404
 from django.shortcuts import get_object_or_404
 from django.utils import timezone
-from django.utils.timezone import now
 from eveuniverse.models import EveType, EveTypeMaterial
 
 from allianceauth.eveonline.models import EveCharacter
@@ -30,6 +27,7 @@ from .models import (
     Character,
     OrePrices,
     Settings,
+    Stats,
 )
 
 logger = get_extension_logger(__name__)
@@ -37,33 +35,27 @@ TASK_DEFAULT_KWARGS = {"time_limit": MININGTAXES_TASKS_TIME_LIMIT, "max_retries"
 
 
 def calctaxes():
-    n = now().date()
-    curmonth = date(year=n.year, month=n.month, day=1)
-    user2taxes = {}
-    characters = Character.objects.all()
-    for character in characters:
-        if character.user is None:
-            continue
-        taxes = character.get_monthly_taxes()
-        total = 0.0
-        for k in taxes.keys():
-            if k != curmonth:
-                total += taxes[k]
-        if character.user not in user2taxes:
-            user2taxes[character.user] = [0.0, 0.0, character]
-        user2taxes[character.user][0] += total
-        if total > user2taxes[character.user][1]:
-            user2taxes[character.user][1] = total
-            user2taxes[character.user][2] = character
-        credits = character.get_lifetime_credits()
-        user2taxes[character.user][0] -= credits
+    s = Stats.load()
+    return s.calctaxes()
 
-    for user in user2taxes.keys():
-        taxes_due = round(user2taxes[user][0], 2)
-        if taxes_due == 0.00:
-            taxes_due = abs(taxes_due)
-        user2taxes[user][0] = taxes_due
-    return user2taxes
+
+def get_user(cid):
+    try:
+        c = EveCharacter.objects.get(character_id=cid)
+        p = c.character_ownership.user.profile
+    except Exception:
+        return None
+    if p is None or p.main_character is None:
+        return None
+    found = None
+    for c in p.user.character_ownerships.all():
+        try:
+            payee = get_object_or_404(Character, eve_character_id=c.character.pk)
+        except Exception:
+            continue
+        found = payee
+        break
+    return found
 
 
 @shared_task(**{**TASK_DEFAULT_KWARGS, **{"bind": True}})
@@ -110,6 +102,11 @@ def update_daily(self):
         update_character(character_pk=character.id, celery=True)
     add_corp_moon_taxes()
     add_tax_credits()
+    # precalc all characters
+    for character in characters:
+        character.precalc_all()
+    s = Stats.load()
+    s.precalc_all()
 
 
 def valid_janice_api_key():
@@ -154,8 +151,8 @@ def get_bulk_prices(type_ids):
         output = {}
         for item in r:
             output[str(item["itemType"]["eid"])] = {
-                "buy": {"max": str(item["top5AveragePrices"]["buyPrice"])},
-                "sell": {"min": str(item["top5AveragePrices"]["sellPrice"])},
+                "buy": {"max": str(item["top5AveragePrices"]["buyPrice5DayMedian"])},
+                "sell": {"min": str(item["top5AveragePrices"]["sellPrice5DayMedian"])},
             }
         r = output
     else:
@@ -181,6 +178,8 @@ def update_all_prices(self):
             include_children=True,
             wait_for_children=True,
         )
+        EveTypeMaterial.objects.update_or_create_api(eve_type=item)
+
         materials = EveTypeMaterial.objects.filter(
             eve_type_id=item.id
         ).prefetch_related("eve_type")
@@ -189,6 +188,7 @@ def update_all_prices(self):
             matset.add(mat.id)
 
     if MININGTAXES_PRICE_METHOD == "Fuzzwork":
+        logger.debug("Using Fuzzwork")
         logger.debug(
             "Price setup starting for %s items from Fuzzworks API from station id %s (%s), this may take up to 30 seconds..."
             % (
@@ -198,6 +198,7 @@ def update_all_prices(self):
             )
         )
     elif MININGTAXES_PRICE_METHOD == "Janice":
+        logger.debug("Using Janice")
         if valid_janice_api_key():
             logger.debug(
                 "Price setup starting for %s items from Janice API for Jita 4-4, this may take up to 30 seconds..."
@@ -257,8 +258,8 @@ def update_all_prices(self):
                 )
 
         # Handling refined material prices
-        logger.debug("Materials price updating...")
         type_ids = list(matset)
+        logger.debug(f"Materials price updating: {len(type_ids)}")
         market_data = {}
         market_data.update(get_bulk_prices(type_ids))
         for mat in matset:
@@ -351,7 +352,10 @@ def add_tax_credits():
                     ).pk,
                 )
             except EveCharacter.DoesNotExist:
-                continue
+                payee = get_user(entry.taxed_id)
+                if payee is None:
+                    continue
+                pass
             except Http404:
                 continue
             payee.tax_credits.update_or_create(
